# Generated by Django 5.2.7 on 2025-10-16 05:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('blog', '0001_initial'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='post',
            name='unique_slug_per_publish_date',
        ),
        migrations.RenameIndex(
            model_name='comment',
            new_name='blog_commen_post_id_7710b1_idx',
            old_name='blog_comment_post_id_8c9f7c_idx',
        ),
        migrations.RenameIndex(
            model_name='comment',
            new_name='blog_commen_created_4e025c_idx',
            old_name='blog_comment_created_5e9e9c_idx',
        ),
        migrations.RenameIndex(
            model_name='post',
            new_name='blog_post_publish_7e8b08_idx',
            old_name='blog_post_publish_8e5d6d_idx',
        ),
        migrations.RenameIndex(
            model_name='post',
            new_name='blog_post_status_02ce19_idx',
            old_name='blog_post_status_3d0b1e_idx',
        ),
        migrations.RenameIndex(
            model_name='post',
            new_name='blog_post_categor_82832f_idx',
            old_name='blog_post_categor_5e9e9c_idx',
        ),
        migrations.RenameIndex(
            model_name='postview',
            new_name='blog_postvi_post_id_e2f6b2_idx',
            old_name='blog_postvie_post_id_9b6d2c_idx',
        ),
        migrations.RenameIndex(
            model_name='postview',
            new_name='blog_postvi_created_fbb95a_idx',
            old_name='blog_postvie_created_5e9e9c_idx',
        ),
        migrations.AddField(
            model_name='post',
            name='view_count',
            field=models.PositiveIntegerField(default=0, help_text='Unique view count'),
        ),
        migrations.AlterField(
            model_name='post',
            name='slug',
            field=models.SlugField(max_length=200, unique_for_date='publish_date'),
        ),
    ]
